﻿//*****************************************************************************
// Description     : Definition of IO functions
// Target Device   : APV8508, APV8104
// Target Platform : Windows, .NET Framework, C#
// Date            : September 2017
// Version         : 1.0
//*****************************************************************************
using System;
using System.IO;

namespace APV8508_sample
{
	public static class Files
	{
		//#########################################################################
		//  Name      : file_write_header
		//  Function  : write header to the text file
		//  Arguments :
		//      in pName    : file name
		//      in now_time : actual measurement time(msec)
		//      in out_cnt  : array of input count rate(cps)
		//      in out_cps  : array of throughput count rate(cps)
		//  Return :
		//       0 : success
		//      -1 : failed to open file
		//#########################################################################
		public static int file_write_header(string pName, uint now_time, uint[] out_cnt, uint[] out_cps)
		{
			int i;

			try {
				// open file(create)
				StreamWriter writer = File.CreateText(pName);

				// write header information
				writer.WriteLine("[header]");
				writer.WriteLine("Real time(s), {0}", now_time/1000);

	            writer.Write("Output count");
	            for (i = 0; i < Defines.MAX_CHNUM; i++) {
	                writer.Write(",{0}", out_cnt[i]);
	            }
	            writer.WriteLine();
	
	            writer.Write("Output rate(cps)");
	            for (i = 0; i < Defines.MAX_CHNUM; i++) {
	                writer.Write(",{0}", out_cps[i]);
	            }
	            writer.WriteLine();

				// close file
				writer.Close();
			}
			catch (Exception) {
				// failed to open file
				return(-1);
			}

			return(0);
		}


		//#########################################################################
		//  Name      : file_write_data
		//  Function  : write data to the text file
		//  Arguments :
		//      in pName : file name
		//      in pBuff : array of data
		//  Return :
		//       0 : success
		//      -1 : failed to open file
		//#########################################################################
		public static int file_write_data(string pName, byte[][] pBuff)
		{
			int i, j;

			try {
				// open file(append)
				StreamWriter writer = File.AppendText(pName);

				writer.WriteLine("[data]");

				// write data in unit of unsigned int
				for (i = 0; i < Device.NUM_DATA; i++) {
					writer.Write( BitConverter.ToUInt32(pBuff[0], i*4) );			// CH1
					for (j = 1; j < Defines.MAX_CHNUM; j++) {						// CH2-
						writer.Write(",{0}", BitConverter.ToUInt32(pBuff[j], i*4) );
					}
					writer.WriteLine();
				}

				// close file
				writer.Close();
			}
			catch (Exception) {
				// failed to open file
				return(-1);
			}

			return(i);
		}

	} // end of class
} // end of namespace

